#!/usr/bin/python

import wx
from wx.lib.embeddedimage import PyEmbeddedImage

pointer = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAl5J"
    "REFUOI11k0tIlFEUx3/n3O8rRSFHw7GoSIsQgsoMrYZaiCsLiRZlCykSgvatgsBF1KZF0SIM"
    "pEKJ2kREtJKejgUi5aoHYovsYYlpaTY63z0txnGmiQ4c7r3n+f8f7hEKpG51sKt1W9BevyZI"
    "lJdolQITs/7L0Fg6ee9Vuuflp/Tz/HjJu5d0thRdOFy//IRTlIrN2NomcCGMPUHGh4g8/vZQ"
    "6mrng9+ngNn8AiXXjxbfTdSEzQL4FRuwhjNYrBZEkR/v0cFzyMQwBiRHF/qO3Zg7AMw6gLOt"
    "RZf3bQkPiQKxjfg9F8EtQ1JTyPw0qMOvb0F/juB+fWBdhdZUlmrFw7fp+7J1TdBw52TxC1XE"
    "iuNEm45CUQVmUQFLQaIUbqQXmX6H92IHr8ztDI40akcYejHASquw1Ff4/blwthnRECkuQ2dA"
    "nUlbo3YEDdWaUJfxez+FzLwGH/2ngEMWvqGBAdBYrYmgspy4CzMGTY1BNI2pZIBbjoHZYpH0"
    "LBIYYlAZIx6oGuqy3nngO0SSo+8LUEgEi/HqjGByjvHKmK3MNLO/MrJlhX/FgMk5xnVwNJ1U"
    "Z7ggg0SdoUFGncto9q1Bzu+cMTiaTmpvf9QtzswFhgsNDfOSw0VdbJCNcc4QZ9bbH3W7z1N8"
    "XFXOqvoNskMcqIAqiII4EMk7NafXHvur1x5Z19JXvn9a7zZt0eZ8jlIwh6zt4bDv23/e574y"
    "sHDzmd2Jx6y8bqNsd4pkUajmEJngu/t8V/slO07BMi3J7lp2te2V9t21koiXUQUwPsWXgTeW"
    "vPXUegbe8Nc6/wGnO+2owwBT9AAAAABJRU5ErkJggg==")
    
    
class CustomSlider(wx.PyPanel):
    """
    Custom Slider class
    """
    
    def __init__(self, parent, id=wx.ID_ANY, value=0.0, range=(0.0, 1.0), size=(-1, 16),
                    pos=wx.DefaultPosition, style=wx.NO_BORDER, name="CustomSlider"):
                    
        """
        Default class constructor.
        @param parent: Parent window. Must not be None.
        @param id: CustomSlider identifier. A value of -1 indicates a default value.
        @param pos: CustomSlider position. If the position (-1, -1) is specified
                    then a default position is chosen.
        @param size: CustomSlider size. If the default size (-1, -1) is specified
                     then a default size is chosen.
        @param style: use wx.Panel styles
        @param name: Window name.
        """
        
        wx.PyPanel.__init__(self, parent, id, pos, size, style, name)
                
        self.value = value
        self.range = range
                
        self.difference = range[1]-range[0]
        #event.GetX() position or Horizontal position across Panel
        self.x = 0 
        #position of pointer
        self.pointerPos = 0 
        
        #Get Pointer's bitmap
        self.bitmap = pointer.GetBitmap()
        
        #Events
        self.Bind(wx.EVT_PAINT, self.OnPaint)
        self.Bind(wx.EVT_MOTION, self.OnMotion)
        self.Bind(wx.EVT_LEFT_DOWN, self.OnLeftDown)
        self.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
        self.Bind(wx.EVT_SIZE, self.OnSize)
                
              
    def OnPaint(self, event=None):
        dc = wx.BufferedPaintDC(self)
        foreColor = self.GetBackgroundColour()
        #solidBrush = wx.Brush('#000000', wx.SOLID)
        dc.SetBackground(wx.Brush(foreColor, wx.SOLID))
        dc.Clear()
        dc.SetPen(wx.Pen("BLACK", 2))
        dc.DrawLine(0,8,self.GetSize()[0],8)
        dc.DrawBitmap(self.bitmap, self.pointerPos, 0)
        event.Skip()
        
    def OnLeftDown(self, event=None):
        #Capture Mouse
        self.CaptureMouse()
        self.getPointerLimitPos(event.GetX())
        self.Refresh()
        checkEvent = wx.CommandEvent(wx.EVT_SLIDER, self.GetId())
        checkEvent.SetEventObject(self)
        self.GetEventHandler().ProcessEvent(checkEvent)
       
    def OnLeftUp(self, event=None):
        #Release Mouse
        if self.GetCapture():
            self.ReleaseMouse()
        checkEvent = wx.CommandEvent(wx.wxEVT_COMMAND_LEFT_CLICK, self.GetId())
        checkEvent.SetEventObject(self)
        self.GetEventHandler().ProcessEvent(checkEvent)
            
    def getPointerLimitPos(self, xPos):
        #limit movement if X position is greater then self.width
        if xPos > self.GetSize()[0]-8: 
            self.pointerPos = self.GetSize()[0]-16
        #limit movement if X position is less then 0
        elif xPos < 8:
            self.pointerPos = 0
        #if X position is between 0-self.width
        else:
            self.pointerPos = xPos-8
        
        #calculate value based on pointer position
        prcnt = float(self.pointerPos)/(self.GetSize()[0]-16)
        self.value =  (self.range[1]-self.range[0])*prcnt+self.range[0]
        

    def OnMotion(self, event=None):
        if self.GetCapture():
            self.getPointerLimitPos(event.GetX())
        self.Refresh()
        

    def OnSize(self, event=None):
        """
        If Panel is getting resize for any reason then calculate pointer's position
        based on it's new size
        """
        #Get the size of Panel
        size = self.GetSize()[0]-16 #16=pointer's width
        
        #Based on panel size and "range" difference calculate pointer position on "panel"
        prcnt = ((self.range[0]-self.value)/self.difference)*100.0
        self.pointerPos = int(abs(size*(prcnt/100)))
        self.Refresh()
        
    def SetValue(self, value):
        self.value = value
                
    def GetValue(self):
        return self.value
        
    def GetRange(self, range):
        self.range = range
              

class Frame(wx.Frame):
    def __init__(self, parent, id, title):
        wx.Frame.__init__(self, parent, id, title, size=(220, 260))
        
        icon =pointer.GetIcon()
        self.SetIcon(icon)
        
        hSizer = wx.BoxSizer(wx.HORIZONTAL)
        self.panel = wx.Panel(self, wx.ID_ANY, style=wx.STATIC_BORDER)
        self.sldr = CustomSlider(self.panel, value=0.5, range=(0.0,1.0), style=wx.NO_BORDER|wx.ALIGN_CENTER_VERTICAL)
        hSizer.Add(self.sldr,  1)
        
        wx.EVT_LEFT_UP(self.sldr, self.OnLeftUp)
        
        self.panel.SetSizer(hSizer)
        self.panel.Fit()
        self.Centre()
        
    def OnLeftUp(self, event=None):
        print self.sldr.GetValue()
        



class MyApp(wx.App):
    def OnInit(self):
        frame = Frame(None, -1, 'Slider Demo')
        frame.Show(True)
        self.SetTopWindow(frame)
        return True

app = MyApp(0)
app.MainLoop()
